@@ -11,7 +11,11 @@ from feedback.settings import FEEDBACK_ATTACHMENT_SIZE
 class BaseFeedbackForm(forms.Form):
 
     class Media:
-        js = ((settings.MEDIA_URL + 'feedback/js/feedback.js'),)
+        if hasattr(settings, 'STATIC_URL'):
+            js = ((settings.STATIC_URL + 'feedback/js/feedback.js'),)
+        else:
+            js = ((settings.MEDIA_URL + 'feedback/js/feedback.js'),)
+
 
     subject = _('feedback')
     
@@ -31,7 +35,9 @@ class BaseFeedbackForm(forms.Form):
         # prepare context for message
         context = self.get_context_data(request)
         message = render_to_string(self.get_template(), context)
-        headers = {'Reply-to': getattr(self, 'email', settings.DEFAULT_FROM_EMAIL)}
+        headers = {}
+        if self.cleaned_data.has_key('email'):
+            headers = {'Reply-to': self.cleaned_data.get('email')}
         mail_managers(self.subject, 
                       message, 
                       attachments=request.FILES, 
